@@ -1,4 +1,4 @@
-/* $Id: script_instance.cpp 23740 2012-01-03 21:32:51Z rubidium $ */
+/* $Id: script_instance.cpp 26057 2013-11-23 13:12:19Z rubidium $ */
 
 /*
  * This file is part of OpenTTD.
@@ -27,6 +27,7 @@
 
 #include "../company_base.h"
 #include "../company_func.h"
+#include "../fileio_func.h"
 
 ScriptStorage::~ScriptStorage()
 {
@@ -48,6 +49,7 @@ static void PrintFunc(bool error_msg, const SQChar *message)
 
 ScriptInstance::ScriptInstance(const char *APIName) :
 	engine(NULL),
+	versionAPI(NULL),
 	controller(NULL),
 	storage(NULL),
 	instance(NULL),
@@ -55,6 +57,7 @@ ScriptInstance::ScriptInstance(const char *APIName) :
 	is_dead(false),
 	is_save_data_on_stack(false),
 	suspend(0),
+	is_paused(false),
 	callback(NULL)
 {
 	this->storage = new ScriptStorage();
@@ -104,6 +107,28 @@ void ScriptInstance::RegisterAPI()
 	squirrel_register_std(this->engine);
 }
 
+bool ScriptInstance::LoadCompatibilityScripts(const char *api_version, Subdirectory dir)
+{
+	char script_name[32];
+	seprintf(script_name, lastof(script_name), "compat_%s.nut", api_version);
+	char buf[MAX_PATH];
+	Searchpath sp;
+	FOR_ALL_SEARCHPATHS(sp) {
+		FioAppendDirectory(buf, MAX_PATH, sp, dir);
+		ttd_strlcat(buf, script_name, MAX_PATH);
+		if (!FileExists(buf)) continue;
+
+		if (this->engine->LoadScript(buf)) return true;
+
+		ScriptLog::Error("Failed to load API compatibility script");
+		DEBUG(script, 0, "Error compiling / running API compatibility script: %s", buf);
+		return false;
+	}
+
+	ScriptLog::Warning("API compatibility script not found");
+	return true;
+}
+
 ScriptInstance::~ScriptInstance()
 {
 	ScriptObject::ActiveInstance active(this);
@@ -142,6 +167,7 @@ void ScriptInstance::GameLoop()
 		this->Died();
 		return;
 	}
+	if (this->is_paused) return;
 	this->controller->ticks++;
 
 	if (this->suspend   < -1) this->suspend++; // Multiplayer suspend, increase up to -1.
@@ -250,6 +276,16 @@ void ScriptInstance::CollectGarbage() const
 	instance->engine->InsertResult(ScriptObject::GetNewGoalID());
 }
 
+/* static */ void ScriptInstance::DoCommandReturnStoryPageID(ScriptInstance *instance)
+{
+	instance->engine->InsertResult(ScriptObject::GetNewStoryPageID());
+}
+
+/* static */ void ScriptInstance::DoCommandReturnStoryPageElementID(ScriptInstance *instance)
+{
+	instance->engine->InsertResult(ScriptObject::GetNewStoryPageElementID());
+}
+
 ScriptStorage *ScriptInstance::GetStorage()
 {
 	return this->storage;
@@ -497,10 +533,23 @@ void ScriptInstance::Save()
 	}
 }
 
-void ScriptInstance::Suspend()
+void ScriptInstance::Pause()
 {
+	/* Suspend script. */
 	HSQUIRRELVM vm = this->engine->GetVM();
 	Squirrel::DecreaseOps(vm, _settings_game.script.script_max_opcode_till_suspend);
+
+	this->is_paused = true;
+}
+
+void ScriptInstance::Unpause()
+{
+	this->is_paused = false;
+}
+
+bool ScriptInstance::IsPaused()
+{
+	return this->is_paused;
 }
 
 /* static */ bool ScriptInstance::LoadObjects(HSQUIRRELVM vm)
